register_embedder_callback

Function register_embedder_callback 

pub fn register_embedder_callback(
    webview_id: WebViewId,
    callback: Box<dyn FnOnce(*mut c_void, *mut c_void) + Send>,
)
Register a callback to be executed on this ScriptThread the next time handle_evaluate_javascript runs for webview_id.

The callback receives (cx, global) as *mut c_void; it is the embedder’s responsibility to cast these to the correct types.