pub struct ServoThreadSafeLayoutNode<'dom> { /* private fields */ }Expand description
A wrapper around a ServoLayoutNode that can be used safely on different threads.
It’s very important that this never mutate anything except this wrapped node and
never access any other node apart from its parent.
Implementations
Sourceimpl<'dom> ServoThreadSafeLayoutNode<'dom>
impl<'dom> ServoThreadSafeLayoutNode<'dom>
Sourcepub fn new(node: ServoLayoutNode<'dom>) -> Self
pub fn new(node: ServoLayoutNode<'dom>) -> Self
Creates a new ServoThreadSafeLayoutNode from the given ServoLayoutNode.
Sourcepub fn is_single_line_text_input(&self) -> bool
pub fn is_single_line_text_input(&self) -> bool
Whether this is a container for the text within a single-line text input. This is used to solve the special case of line height for a text entry widget. https://html.spec.whatwg.org/multipage/#the-input-element-as-a-text-entry-widget
pub fn selected_style( &self, context: &SharedStyleContext<'_>, ) -> Arc<ComputedValues>