Module textinput

Module textinput 

Common handling of keyboard input and state management for text input controls

Structs

ClipboardEventFlags
Resulting action to be taken by the owner of a text input that is handling a clipboard event.
ClipboardEventReaction
TextInput
Encapsulated state for handling keyboard input in a single or multiline text input control.

Enums

Direction
The direction in which to delete a character.
InputType
https://www.w3.org/TR/input-events-2/#interface-InputEvent-Attributes
IsComposing
KeyReaction
Resulting action to be taken by the owner of a text input that is handling an event.
Lines
Selection
SelectionDirection