Common handling of keyboard input and state management for text input controls
Structs
- Clipboard
Event Flags - Resulting action to be taken by the owner of a text input that is handling a clipboard event.
- Clipboard
Event Reaction - Text
Input - Encapsulated state for handling keyboard input in a single or multiline text input control.
Enums
- Direction
- The direction in which to delete a character.
- Input
Type - https://www.w3.org/TR/input-events-2/#interface-InputEvent-Attributes
- IsComposing
- KeyReaction
- Resulting action to be taken by the owner of a text input that is handling an event.
- Lines
- Selection
- Selection
Direction